### Replication code for graphs in Hall and Snyder
### Note: Stata code MUST BE RUN FIRST
### Various datasets loaded here are generated in the Stata code 
### This code also requires several supplemental datasets provided in the Replication directory

par.hall <- function(..., mgp=c(0,.5,0)) {
  par(..., mgp=mgp)
}

library(foreign)

### FIGURE 1
### histogram of heaping 
data <- read.dta("pct_for_r.dta")

pdf(width=8, height=3.6, file="distributions.pdf")
par.hall(mfrow=c(1,3), mar=c(0.5,2.5,2.5,0)+0.1, oma=c(5,0,3,1)+0.1)
hist(data$vote_12_pct, xlim=c(30, 103), yaxt="n", breaks=seq(30, 105, 5), ylab="", main="Percentage of Vote \n to Top 2 Candidates", right=F, ylim=c(0,1200), col="gray50", xlab="")
axis(side=2, las=1)
hist(data$indiv_12_pct, xlim=c(30, 103), yaxt="n", breaks=seq(30, 105, 5), ylab="", main="Percentage of Individual Donations \n to Top 2 Candidates", right=F, ylim=c(0,1200), col="gray50", xlab="")
hist(data$group_12_pct, xlim=c(30, 103), yaxt="n", breaks=seq(30, 105, 5), ylab="", main="Percentage of Group Donations \n to Top 2 Candidates", right=F, ylim=c(0,1200), col="gray50", xlab="")
dev.off()

### FIGURE 2
### number of candidates and support for lesser candidates
data.vote <- read.dta("vote_for_r.dta")
data.indiv <- read.dta("indiv_for_r.dta")
data.group <- read.dta("group_for_r.dta")

pdf(width=12, height=4, file="share_across_n.pdf")
par.hall(mfrow=c(1,3), mar=c(4,3,2.5,0)+0.1, oma=c(2,0,3,1)+0.1)

plot(x=data.vote$n, y=data.vote$vote_other_pct_High, pch=16, ylim=c(0,50), xlab="", ylab="", main="", xlim=c(3,7), cex.lab=1.4, cex.axis=1.4, cex.main=1.5, yaxt="n")
lines(x=data.vote$n, y=data.vote$vote_other_pct_High, lwd=3)
points(x=data.vote$n, y=data.vote$vote_other_pct_Cong, pch=16, col="darkred")
lines(x=data.vote$n, y=data.vote$vote_other_pct_Cong, lwd=3, col="darkred")
points(x=data.vote$n, y=data.vote$vote_other_pct_Oth, pch=16, col="dodgerblue")
lines(x=data.vote$n, y=data.vote$vote_other_pct_Oth, lwd=3, col="dodgerblue")
text(x=6, y=44, col="dodgerblue", "Other Offices", cex=1.3)
text(x=5.5, y=34, col="darkred", "U.S. House", cex=1.3)
text(x=6, y=27, "Governor and Senate", cex=1.3)
mtext(side=3, "Percentage of Vote \n to Lesser Candidates", font=2, cex=1.2, line=1.5)
mtext(side=1, line=2, "# Candidates", cex=1)
axis(side=2, las=1, cex.axis=1.4)

plot(x=data.indiv$n, y=data.indiv$indiv_other_pct_High, pch=16, ylim=c(0,50), xlab="", ylab="", main="", yaxt="n", cex.lab=1.4, cex.axis=1.4, cex.main=1.5)
lines(x=data.indiv$n, y=data.indiv$indiv_other_pct_High, lwd=3)
points(x=data.indiv$n, y=data.indiv$indiv_other_pct_Cong, pch=16, col="darkred")
lines(x=data.indiv$n, y=data.indiv$indiv_other_pct_Cong, lwd=3, col="darkred")
points(x=data.indiv$n, y=data.indiv$indiv_other_pct_Oth, pch=16, col="dodgerblue")
lines(x=data.indiv$n, y=data.indiv$indiv_other_pct_Oth, lwd=3, col="dodgerblue")
text(x=3.7, y=16, col="dodgerblue", "Other Offices", cex=1.3)
text(x=6.3, y=27, col="darkred", "U.S. House", cex=1.3)
text(x=6, y=5.4, "Governor and Senate", cex=1.3)
mtext(side=3, "Percentage of Individual Contributions \n to Lesser Candidates", font=2, cex=1.2, line=1.5)
mtext(side=1, line=2, "# Candidates", cex=1)

plot(x=data.group$n, y=data.group$group_other_pct_High, pch=16, ylim=c(0,50), xlab="", ylab="", main="", yaxt="n", cex.lab=1.4, cex.axis=1.4, cex.main=1.5)
lines(x=data.group$n, y=data.group$group_other_pct_High, lwd=3)
points(x=data.group$n, y=data.group$group_other_pct_Cong, pch=16, col="darkred")
lines(x=data.group$n, y=data.group$group_other_pct_Cong, lwd=3, col="darkred")
points(x=data.group$n, y=data.group$group_other_pct_Oth, pch=16, col="dodgerblue")
lines(x=data.group$n, y=data.group$group_other_pct_Oth, lwd=3, col="dodgerblue")
text(x=3.5, y=13, col="dodgerblue", "Other Offices", cex=1.3)
text(x=6, y=11, col="darkred", "U.S. House", cex=1.3)
text(x=5.3, y=1.4, "Governor and Senate", cex=1.3)
mtext(side=3, "Percentage of Group Contributions \n to Lesser Candidates", cex=1.2, font=2, line=1.5)
mtext(side=1, line=2, "# Candidates", cex=1)

dev.off()

### FIGURE 3
### figure on competition
data.cong <- read.csv("cong.csv")
data.high <- read.csv("high.csv")
data.other <- read.csv("other.csv")

pdf(file="competition.pdf")
plot(x=data.cong$compet, y=data.cong$vote_2_2n_pct, col="darkgreen", ylim=c(50,70), pch=2, xlab="Competition", ylab="% Votes Not Wasted", cex.lab=1.2, yaxt="n")
abline(lm(data.cong$vote_2_2n_pct ~ data.cong$compet), col="darkgreen")
points(x=data.high$compet, y=data.high$vote_2_2n_pct, pch=1, col="dodgerblue")
abline(lm(data.high$vote_2_2n_pct ~ data.high$compet), col="dodgerblue")
points(x=data.other$compet, y=data.other$vote_2_2n_pct, pch=3, col="purple")
abline(lm(data.other$vote_2_2n_pct ~ data.other$compet), col="purple")
legend("topleft", pch=c(1,2,3), col=c("dodgerblue", "darkgreen", "purple"), c("Higher Offices", "U.S. House", "Lower Offices"), cex=1.3)
text(x=-5, y=62, "Higher Offices", col="dodgerblue", cex=1.3)
text(x=-9, y=54, "Lower Offices", col="purple", cex=1.3)
text(x=13, y=60.8, "U.S. House", col="darkgreen", cex=1.3)
axis(side=2, las=1)
dev.off()


### FIGURE 4
### balance stats
pre.data <- read.dta("whole_sample_for_R.dta")
post.data <- read.dta("merged_sample_for_r.dta")

balance.stat <- function(data, covariate){
  data <- na.omit(data)
  tmp <- (data[,covariate] - mean(data[,covariate])) / sd(data[,covariate])
  stat <- mean(tmp[data$instate==1], na.rm=T) - mean(tmp[data$instate==0], na.rm=T)
  return(stat)
}

covars <- c("hispanic", "black_pc", "married_households", "crime", "social_security", "fed_grants_pc", "population", "highschool", "median_income")

balance.stats <- sapply(covars, function(x) balance.stat(pre.data,x))
balance.stats.match <- sapply(covars, function(x) balance.stat(post.data, x))

covar.label <- c("% Hispanic", "% Black", "Married Households", "Crime Rate", "Social Security Beneficiaries", "Federal Grants Per Capita", "Population", "High School Graduates", "Median Household Income")

pdf(file="balance_plot.pdf")
par(bg="white", mar=c(5, 2, 0, 1)+0.1, oma=c(2, 1, 0, 0))
dotchart(balance.stats, pch=17, xlab="", labels=covar.label, cex=1.2, xlim=c(-.5, .5))
points(balance.stats, 1:length(covars),pch=17, col="red")
points(balance.stats.match, 1:length(covars), col="navy", pch=19)
abline(v=0, lty=2, col="black")
legend("bottomleft", col=c("red","navy"),pch=c(17,19), c("All Counties","Adjacent Counties"))
mtext(side=1, "Standardized Difference-in-Means: \n In-State minus Out-Of-State", cex=1.4, line=3.5)
dev.off()

### FIGURE 5
#### map of counties graph
data <- read.dta("final_map_for_r.dta")
library(maps)
data$cols <- ifelse(data$instate==1, "violet", "darkgreen")

# bug in R map has to be removed
to.add <- data[data$polyname == "texas,collin",]
data <- data[data$polyname != "texas,collin",]

pdf(file="adjacent_counties2.pdf")
map("state", lwd=3)
map("county", add=T, col="darkgray")
for (st in unique(data$state)) {
  map("county", data[data$state==st,]$polyname, add=T, bor="darkgray", col=data[data$state==st,]$cols, fill=T)
}
map("county", to.add$polyname, add=T, bor="darkgray", col="violet", fill=T)
map("county", "texas,collingsworth", add=T, bor="darkgray", col="white", fill=T)
map("state", lwd=2, add=T)
#title(main="Adjacent Counties Used in Analysis")
dev.off()

### FIGURE A1
### appendix figure on number of candidates by office type
data <- read.dta("hall_snyder_analysis.dta")
pdf(file="num_candidates.pdf")
par(mfrow=c(3,1), oma=c(3,3,3,3), mar=c(2, 3, 1, 3))
hist(data[data$high==1,]$n, xaxt="n", yaxt="n", xlab="", ylab="", main="High Offices", col="gray50", breaks=c(2,3,4,5,6,7))
axis(side=2, las=1)
hist(data[data$cong==1,]$n,  xaxt="n", yaxt="n", xlab="", ylab="", main="Congress", breaks=c(2,3,4,5,6,7), col="gray50")
axis(side=2, las=1)
hist(data[data$othr==1,]$n,  xaxt="n", yaxt="n", xlab="", ylab="", main="Lesser Offices", breaks=c(2,3,4,5,6,7), col="gray50")
axis(side=2, las=1)
axis(side=1, at=2.5:6.5, labels=3:7)
mtext(side=1, line=2.5, "Number of Candidates", cex=.8)
dev.off()
