************************************************
***** Replication Code for Hall and Snyder *****
***** QJPS, 2015 						   *****
************************************************


*********************************************************
* Note:
* This code MUST be run before the R graphics code
* The R code relies on datasets output in this code.
*
* Also note:
* This code requires four datasets:
* hall_snyder_analysis.dta
* state_pop.dta
* adjacency1.dta
* adjacency2.dta
*
* Finally: you MUST have binscatter installed
* ssc install binscatter
*********************************************************

*******************
* Set directory if needed
* cd xxxxxx
******************


#delimit ;

/* Spending data for Table 1 */

use hall_snyder_analysis, clear;

/* bring in population data just for this analysis */
sort state year;
merge state year using state_pop;

keep if _merge == 3;
drop _merge;

egen ndists = max(dist), by(state year);

gen pop_dist = .;
replace pop_dist = pop if office != "H";
replace pop_dist = pop/ndists if office == "H";

replace total_money = total_money / pop_dist;

/* Total money across offices for Table 1 */
/* This is only table not transcribed in Stata */
tab office_type, summarize(total_money);



/* TABLE 2 */
use hall_snyder_analysis, clear;


xi: reg vote_12_pct high cong   i.n    if indiv_other_pct != .  & group_other_pct != .    , robust;
local high1 = _b[high];
local se1 = _se[high];
local cong1 = _b[cong];
local secong1 = _se[cong];
local low1 = _b[_cons];
local selow1 = _se[_cons];
local n1 = e(N);

xi: reg indiv_12_pct high cong   i.n   if group_other_pct != .   , robust;
local high2 = _b[high];
local se2 = _se[high];
local cong2 = _b[cong];
local secong2 = _se[cong];
local low2 = _b[_cons];
local selow2 = _se[_cons];
local n2 = e(N);

xi: reg group_12_pct  high cong   i.n   if indiv_other_pct != .   , robust;
local high3 = _b[high];
local se3 = _se[high];
local cong3 = _b[cong];
local secong3 = _se[cong];
local low3 = _b[_cons];
local selow3 = _se[_cons];
local n3 = e(N);

xi: reg vote_12_pct high cong i.n , robust;
local high_all = _b[high];
local sehigh4 = _se[high];
local cong_all = _b[cong];
local secong4 = _se[cong];
local low4 = _b[_cons];
local selow4 = _se[_cons];
local n4 = e(N);

capture log close;
quietly {;
log using table1.tex, text replace;

set linesize 255;

noisily display "";
noisily display "\begin{table}[t] \caption{{\bf Percent of Votes and Donations to Top 2 Candidates Across Offices, 1990-2010.}";
noisily display "Higher offices, where more information is avaiable, exhbit fewer wasted votes and donations than lower offices.  Across all offices, donors act more strategically than voters. \label{tab:main}}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lccccc}";
noisily display "\toprule \toprule";
noisily display "& All Races & & \multicolumn{3}{c}{Races with Donation Data}\\";
noisily display "\cline{2-2} \cline{4-6} \\[-3mm]";
noisily display "     & Vote (\%)          & &  Vote (\%)    & \shortstack{Individual \\ Donations (\%) } & \shortstack{Group \\ Donations (\%)} \\ \midrule\midrule \\[-4mm]";
noisily display "Constant (Other Offices)     & " %4.2f `low4'     " [" %4.2f `selow4'  "] & & " %4.2f `low1'  " [" %4.2f `selow1'  "] & " %4.2f `low2'  " [" %4.2f `selow2'  "] & " %4.2f `low3'  " [" %4.2f `selow3'  "] \\[1.5mm] ";
noisily display "U.S. House & " %4.2f `cong_all' " [" %4.2f `secong4' "] & & " %4.2f `cong1' " [" %4.2f `secong1' "] & " %4.2f `cong2' " [" %4.2f `secong2' "] & " %4.2f `cong3' " [" %4.2f `secong3' "] \\[1.5mm]";
noisily display "High Offices  & " %4.2f `high_all' " [" %4.2f `sehigh4' "] & & " %4.2f `high1' " [" %4.2f `se1'     "] & " %4.2f `high2' " [" %4.2f `se2'     "] & " %4.2f `high3' " [" %4.2f `se3'     "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE & Yes & & Yes & Yes & Yes \\";
noisily display " N   & " %4.0f `n4'        "  & & " %4.0f `n1'   "  & " %4.0f `n2'        "  & " %4.0f `n3'        "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{6}{p{\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category for estimated coefficients.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};




/* Re-do with state FE for Appendix */
/* Table A4 */

use hall_snyder_analysis, clear;


xi: areg vote_12_pct high cong   i.n    if indiv_other_pct != .  & group_other_pct != .    , a(state) robust;
local high1 = _b[high];
local se1 = _se[high];
local cong1 = _b[cong];
local secong1 = _se[cong];
local low1 = _b[_cons];
local selow1 = _se[_cons];
local n1 = e(N);

xi: areg indiv_12_pct high cong   i.n   if group_other_pct != .   , a(state) robust;
local high2 = _b[high];
local se2 = _se[high];
local cong2 = _b[cong];
local secong2 = _se[cong];
local low2 = _b[_cons];
local selow2 = _se[_cons];
local n2 = e(N);

xi: areg group_12_pct  high cong   i.n   if indiv_other_pct != .   , a(state) robust;
local high3 = _b[high];
local se3 = _se[high];
local cong3 = _b[cong];
local secong3 = _se[cong];
local low3 = _b[_cons];
local selow3 = _se[_cons];
local n3 = e(N);

xi: areg vote_12_pct high cong i.n , a(state) robust;
local high_all = _b[high];
local sehigh4 = _se[high];
local cong_all = _b[cong];
local secong4 = _se[cong];
local low4 = _b[_cons];
local selow4 = _se[_cons];
local n4 = e(N);

capture log close;
quietly {;
set linesize 255;
log using table1_state_fes.tex, text replace;

noisily display "";
noisily display "\begin{table}[t] \caption{{\bf Percent of Votes and Donations to Top 2 Candidates Across Offices, 1990-2010.}";
noisily display "Higher offices, where more information is avaiable, exhbit fewer wasted votes and donations than lower offices.  Across all offices, donors act more strategically than voters. \label{tab:state_fes}}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lccccc}";
noisily display "\toprule \toprule";
noisily display "& All Races & & \multicolumn{3}{c}{Races with Donation Data}\\";
noisily display "\cline{2-2} \cline{4-6} \\[-3mm]";
noisily display "     & Vote (\%)          & &  Vote (\%)    & \shortstack{Individual \\ Donations (\%) } & \shortstack{Group \\ Donations (\%)} \\ \midrule\midrule \\[-4mm]";
noisily display "Constant (Other Offices)     & " %4.2f `low4'     " [" %4.2f `selow4'  "] & & " %4.2f `low1'  " [" %4.2f `selow1'  "] & " %4.2f `low2'  " [" %4.2f `selow2'  "] & " %4.2f `low3'  " [" %4.2f `selow3'  "] \\[1.5mm] ";
noisily display "U.S. House & " %4.2f `cong_all' " [" %4.2f `secong4' "] & & " %4.2f `cong1' " [" %4.2f `secong1' "] & " %4.2f `cong2' " [" %4.2f `secong2' "] & " %4.2f `cong3' " [" %4.2f `secong3' "] \\[1.5mm]";
noisily display "High Offices  & " %4.2f `high_all' " [" %4.2f `sehigh4' "] & & " %4.2f `high1' " [" %4.2f `se1'     "] & " %4.2f `high2' " [" %4.2f `se2'     "] & " %4.2f `high3' " [" %4.2f `se3'     "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE & Yes & & Yes & Yes & Yes \\";
noisily display "State FE & Yes & & Yes & Yes & Yes \\";
noisily display " N   & " %4.0f `n4'        "  & & " %4.0f `n1'   "  & " %4.0f `n2'        "  & " %4.0f `n3'        "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{6}{p{\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category for estimated coefficients.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};



/* Analysis with no incumbents for Appendix */
/* Table A1 */

preserve;
keep if inc==0;

xi: reg vote_12_pct high cong   i.n    if indiv_other_pct != .  & group_other_pct != .    , robust;
local high1 = _b[high];
local se1 = _se[high];
local cong1 = _b[cong];
local secong1 = _se[cong];
local low1 = _b[_cons];
local selow1 = _se[_cons];
local n1 = e(N);

xi: reg indiv_12_pct high cong   i.n   if group_other_pct != .   , robust;
local high2 = _b[high];
local se2 = _se[high];
local cong2 = _b[cong];
local secong2 = _se[cong];
local low2 = _b[_cons];
local selow2 = _se[_cons];
local n2 = e(N);

xi: reg group_12_pct  high cong   i.n   if indiv_other_pct != .   , robust;
local high3 = _b[high];
local se3 = _se[high];
local cong3 = _b[cong];
local secong3 = _se[cong];
local low3 = _b[_cons];
local selow3 = _se[_cons];
local n3 = e(N);

xi: reg vote_12_pct high cong i.n , robust;
local high_all = _b[high];
local sehigh4 = _se[high];
local cong_all = _b[cong];
local secong4 = _se[cong];
local low4 = _b[_cons];
local selow4 = _se[_cons];
local n_all = e(N);

capture log close;
quietly {;
log using table_no_inc.tex, text replace;

noisily display "";
noisily display "\begin{table}[h] \caption{\bf Percent of Votes and Donations to Top 2 Candidates Across Offices, No Incumbents in Race, 1990-2010.} \label{tab:noinc}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lccccc}";
noisily display "\toprule \toprule";
noisily display "& All Races & & \multicolumn{3}{c}{Races with Donation Data}\\";
noisily display "\cline{2-2} \cline{4-6} \\[-3mm]";
noisily display "     & Vote (\%)          & &  Vote (\%)    & \shortstack{Individual \\ Donations (\%) } & \shortstack{Group \\ Donations (\%)} \\ \midrule\midrule \\[-4mm]";
noisily display "Constant (Other Offices)     & " %4.2f `low4'     " [" %4.2f `selow4'  "] & & " %4.2f `low1'  " [" %4.2f `selow1'  "] & " %4.2f `low2'  " [" %4.2f `selow2'  "] & " %4.2f `low3'  " [" %4.2f `selow3'  "] \\[1.5mm] ";
noisily display "U.S. House & " %4.2f `cong_all' " [" %4.2f `secong4' "] & & " %4.2f `cong1' " [" %4.2f `secong1' "] & " %4.2f `cong2' " [" %4.2f `secong2' "] & " %4.2f `cong3' " [" %4.2f `secong3' "] \\[1.5mm]";
noisily display "High Offices  & " %4.2f `high_all' " [" %4.2f `sehigh4' "] & & " %4.2f `high1' " [" %4.2f `se1'     "] & " %4.2f `high2' " [" %4.2f `se2'     "] & " %4.2f `high3' " [" %4.2f `se3'     "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE  & Yes & & Yes & Yes & Yes \\";
noisily display " N   & " %4.0f `n_all'        "  & & " %4.0f `n1'   "  & " %4.0f `n2'        "  & " %4.0f `n3'        "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{6}{p{\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category for estimated coefficients.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};


restore;



/* TABLE 3 */

xi: reg vote_2_2n_pct  high cong       i.n        , robust;
local high5 = _b[high];
local sehigh5 = _se[high];
local cong5 = _b[cong];
local secong5 = _se[cong];
local low5 = _b[_cons];
local selow5 = _se[_cons];
local n1 = e(N);

xi: reg vote_2_2n_pct  high cong high_compet cong_compet compet i.n        , robust;
local high6 = _b[high];
local sehigh6 = _se[high];
local cong6 = _b[cong];
local secong6 = _se[cong];
local low6 = _b[_cons];
local selow6 = _se[_cons];
local high_compet6 = _b[high_compet];
local sehigh_compet6 = _se[high_compet];
local cong_compet6 = _b[cong_compet];
local secong_compet6 = _se[cong_compet];
local low_compet6 = _b[compet];
local selow_compet6 = _se[compet];
local n2 = e(N);

test cong_compet = high_compet;


capture log close;
quietly {;
set linesize 255;
log using table2.tex, text replace;

noisily display "";
noisily display "\begin{table}[t] \caption{\bf Percent of Votes Not Cast For Winning Candidate That Go to Second-Place Candidates Across Offices, 1990-2010.} \label{tab:second}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lcc}";
noisily display "\toprule \toprule";
noisily display "& Percent to Candidate 2 & Percent to Candidate 2 \\";
noisily display "\midrule";
noisily display "Constant (Lower Offices)      & " %4.2f `low5'  " [" %4.2f `selow5'  "] & " %4.2f `low6'  " [" %4.2f `selow6'  "] \\[1.5mm] ";
noisily display "U.S. House  & " %4.2f `cong5' " [" %4.2f `secong5' "] & " %4.2f `cong6' " [" %4.2f `secong6' "] \\[1.5mm]";
noisily display "High   & " %4.2f `high5' " [" %4.2f `sehigh5' "] & " %4.2f `high6' " [" %4.2f `sehigh6' "] \\[1.5mm]";
noisily display "Competition (Lower Offices)   & --   & " %4.2f `low_compet6'  " [" %4.2f `selow_compet6'  "] \\[1.5mm] ";
noisily display "U.S. House $\times$ Competition & --   & " %4.2f `cong_compet6' " [" %4.2f `secong_compet6' "] \\[1.5mm]";
noisily display "High $\times$ Competition  & --   & " %4.2f `high_compet6' " [" %4.2f `sehigh_compet6' "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE & Yes & Yes \\";
noisily display "N   & " %4.0f `n1'  "  & " %4.0f `n2'     "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{3}{p{.9\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};


/* Re-do with State FEs for Appendix */
/* Table A5 */

xi: areg vote_2_2n_pct  high cong       i.n        , a(state) robust;
local high5 = _b[high];
local sehigh5 = _se[high];
local cong5 = _b[cong];
local secong5 = _se[cong];
local low5 = _b[_cons];
local selow5 = _se[_cons];
local n1 = e(N);

xi: areg vote_2_2n_pct  high cong high_compet cong_compet compet i.n        , a(state) robust;
local high6 = _b[high];
local sehigh6 = _se[high];
local cong6 = _b[cong];
local secong6 = _se[cong];
local low6 = _b[_cons];
local selow6 = _se[_cons];
local high_compet6 = _b[high_compet];
local sehigh_compet6 = _se[high_compet];
local cong_compet6 = _b[cong_compet];
local secong_compet6 = _se[cong_compet];
local low_compet6 = _b[compet];
local selow_compet6 = _se[compet];
local n2 = e(N);

test cong_compet = high_compet;


capture log close;
quietly {;
set linesize 255;
log using table2_state_fes.tex, text replace;

noisily display "";
noisily display "\begin{table}[t] \caption{\bf Percent of Votes Not Cast For Winning Candidate That Go to Second-Place Candidates Across Offices, 1990-2010.} \label{tab:second_fes}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lcc}";
noisily display "\toprule \toprule";
noisily display "& Percent to Candidate 2 & Percent to Candidate 2 \\";
noisily display "\midrule";
noisily display "Constant (Lower Offices)      & " %4.2f `low5'  " [" %4.2f `selow5'  "] & " %4.2f `low6'  " [" %4.2f `selow6'  "] \\[1.5mm] ";
noisily display "U.S. House  & " %4.2f `cong5' " [" %4.2f `secong5' "] & " %4.2f `cong6' " [" %4.2f `secong6' "] \\[1.5mm]";
noisily display "High   & " %4.2f `high5' " [" %4.2f `sehigh5' "] & " %4.2f `high6' " [" %4.2f `sehigh6' "] \\[1.5mm]";
noisily display "Competition (Lower Offices)   & --   & " %4.2f `low_compet6'  " [" %4.2f `selow_compet6'  "] \\[1.5mm] ";
noisily display "U.S. House $\times$ Competition & --   & " %4.2f `cong_compet6' " [" %4.2f `secong_compet6' "] \\[1.5mm]";
noisily display "High $\times$ Competition  & --   & " %4.2f `high_compet6' " [" %4.2f `sehigh_compet6' "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE & Yes & Yes \\";
noisily display "State FE & Yes & Yes \\";
noisily display "N   & " %4.0f `n1'  "  & " %4.0f `n2'     "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{3}{p{.9\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};

/* Save off data for R graph */
preserve;
keep vote_2_2n_pct high cong othr compet;
saveold for_r_graph2, version(12) replace;
restore;


/* Table without incs for Appendix */
/* Table A2 */
preserve;
keep if inc==0;

xi: reg vote_2_2n_pct  high cong       i.n        , robust;
local high5 = _b[high];
local sehigh5 = _se[high];
local cong5 = _b[cong];
local secong5 = _se[cong];
local low5 = _b[_cons];
local selow5 = _se[_cons];
local n1 = e(N);

xi: reg vote_2_2n_pct  high cong high_compet cong_compet compet i.n        , robust;
local high6 = _b[high];
local sehigh6 = _se[high];
local cong6 = _b[cong];
local secong6 = _se[cong];
local low6 = _b[_cons];
local selow6 = _se[_cons];
local high_compet6 = _b[high_compet];
local sehigh_compet6 = _se[high_compet];
local cong_compet6 = _b[cong_compet];
local secong_compet6 = _se[cong_compet];
local low_compet6 = _b[compet];
local selow_compet6 = _se[compet];
local n2 = e(N);



capture log close;
quietly {;
set linesize 255;
log using table2_no_inc.tex, text replace;

noisily display "";
noisily display "\begin{table}[h] \caption{\bf Percent of Votes Not Cast For Winning Candidate That Go to Second-Place Candidates Across Offices, No Incumbents, 1990-2010.} \label{tab:second_noinc}";
noisily display "\begin{center}";
noisily display "\begin{tabular}{lcc}";
noisily display "\toprule \toprule";
noisily display "& Percent to Candidate 2 & Percent to Candidate 2 \\";
noisily display "\midrule";
noisily display "Constant (Lower Offices)      & " %4.2f `low5'  " [" %4.2f `selow5'  "] & " %4.2f `low6'  " [" %4.2f `selow6'  "] \\[1.5mm] ";
noisily display "U.S. House  & " %4.2f `cong5' " [" %4.2f `secong5' "] & " %4.2f `cong6' " [" %4.2f `secong6' "] \\[1.5mm]";
noisily display "High   & " %4.2f `high5' " [" %4.2f `sehigh5' "] & " %4.2f `high6' " [" %4.2f `sehigh6' "] \\[1.5mm]";
noisily display "Competition (Lower Offices)  & --   & " %4.2f `low_compet6'  " [" %4.2f `selow_compet6'  "] \\[1.5mm] ";
noisily display "U.S. House $\times$ Competition & --   & " %4.2f `cong_compet6' " [" %4.2f `secong_compet6' "] \\[1.5mm]";
noisily display "High $\times$ Competition  & --   & " %4.2f `high_compet6' " [" %4.2f `sehigh_compet6' "] \\[1.5mm]";
noisily display "\midrule";
noisily display "\# Candidates FE & Yes & Yes  \\";
noisily display "N   & " %4.0f `n1'  "  & " %4.0f `n2'     "  \\ ";
noisily display "\bottomrule\bottomrule \\[-4mm]";
noisily display "\multicolumn{3}{p{.7\textwidth}}{Regression coefficients from Equation \ref{eq:offices}.  Lesser offices are omitted category.  Robust standard errors in brackets.}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};

restore;



/* CREATE DATA FOR BINNED PLOTS IN PAPER */
preserve;
binscatter vote_2_2n_pct compet if high == 1, savedata(high) controls(_* cong othr cong_compet othr_compet) replace;

binscatter vote_2_2n_pct compet if cong == 1, savedata(cong) controls(_* high othr high_compet othr_compet) replace;

binscatter vote_2_2n_pct compet if othr==1, savedata(other) controls(_* cong high high_compet cong_compet) replace;

restore;



/* Data for R graph on percentages */
preserve;
keep  if indiv_12_pct != . & group_12_pct != .;
keep indiv_12_pct group_12_pct vote_12_pct;
saveold "pct_for_r.dta", replace version(12);
restore;


/* voter data for R graph on percentages */
preserve;

gen vote_other_pct_High = vote_other_pct if office_type == "High";
gen vote_other_pct_Cong = vote_other_pct if office_type == "Cong";
gen vote_other_pct_Oth  = vote_other_pct if office_type == "Othr" ;

collapse (mean) vote_other_pct_*, by(n);

saveold vote_for_r, replace version(12);

restore;

preserve;
gen indiv_other_pct_High = indiv_other_pct if office_type == "High";
gen indiv_other_pct_Cong = indiv_other_pct if office_type == "Cong";
gen indiv_other_pct_Oth  = indiv_other_pct if office_type == "Othr" ;

collapse (mean) indiv_other_pct_*, by(n);

saveold indiv_for_r, replace version(12);


restore;

#delimit ;
gen group_other_pct_High = group_other_pct if office_type == "High";
gen group_other_pct_Cong = group_other_pct if office_type == "Cong";
gen group_other_pct_Oth  = group_other_pct if office_type == "Othr" ;

collapse (mean) group_other_pct_*, by(n);

saveold group_for_r, replace version(12);




/* Counties analyses */
/* Table 4 */

use adjacency1, clear;

areg v12 instate, a(race) cluster(race);
local treat1 = _b[instate];
local se1 = _se[instate];
local n1 = e(N);
local c1 = _b[_cons];
local sec1 = _se[_cons];

areg v12 instate if tot_q_major == 0 & tot_q_stleg == 0, a(race) cluster(race);
local treat2 = _b[instate];
local se2 = _se[instate];
local n2 = e(N);
local c2 = _b[_cons];
local sec2 = _se[_cons];



use adjacency2, clear;


areg county_vote instate, a(race) cluster(race);
local treat3 = _b[instate];
local se3 = _se[instate];
local n3 = e(N);
local c3 = _b[_cons];
local sec3 = _se[_cons];

areg county_vote instate if tot_q_major == 0 & tot_q_stleg == 0, a(race) cluster(race);
local treat4 = _b[instate];
local se4 = _se[instate];
local n4 = e(N);
local c4 = _b[_cons];
local sec4 = _se[_cons];


set linesize 200;
capture log close;

quietly {;
log using incumbency_table.tex, text replace;
noisily display "";
noisily display "\begin{table}[t] \caption{{\bf County-Level Analysis.}  Counties in in-state media markets, which receive more information about elections,";
noisily display " exhibit less vote wasting than counties in out-of-state media markets. \label{tab:county}}";
noisily display "\begin{center}";
noisily display "\footnotesize";
noisily display "\begin{tabular}{l*{5}{c}}";
noisily display "\toprule\toprule";
noisily display " & \multicolumn{2}{c}{All Counties} & & \multicolumn{2}{c}{Adjacent Counties} \\";
noisily display "   \cline{2-3}  \cline{5-6} \\ ";
noisily display " & \shortstack{Vote Pct,\\ Top 2} & \shortstack{Vote Pct,\\ Top 2} & & \shortstack{Vote Pct,\\ Top 2} & \shortstack{Vote Pct,\\ Top 2}\\";
noisily display " \midrule ";
noisily display " In-State Media Market ($\beta_1$) & " %4.2f `treat1' " & " %4.2f `treat2' " & & " %4.2f `treat3' " & " %4.2f `treat4' " \\[1mm]";
noisily display " & (" %4.2f `se1' ") & (" %4.2f `se2' ") & & (" %4.2f `se3' ") & (" %4.2f `se4' ") \\[1mm]";

noisily display " Out-of-State Media Market ($\beta_0$) & " %4.2f `c1' " & " %4.2f `c2' " & & " %4.2f `c3' " & " %4.2f `c4' " \\[1mm]";
noisily display " & (" %4.2f `sec1' ") & (" %4.2f `sec2' ") & & (" %4.2f `sec3' ") & (" %4.2f `sec4' ") \\[1mm]";

noisily display "\midrule";
noisily display " N & " %6.0fc `n1' " & " %5.0fc `n2' " & & " %5.0fc `n3' " & " %5.0fc `n4' " \\ ";
noisily display " Race Fixed Effects & Yes & Yes & & Yes & Yes \\";
noisily display "Races Included & All & No Experience & & All & No Experience \\";
noisily display " \bottomrule \bottomrule ";
noisily display "\multicolumn{6}{p{.8\textwidth}}{Robust standard errors clustered by race in parentheses.  Out-of-State Media Markets are the omitted category ($\beta_0$).}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};



/* Re-do without incumbents for Appendix */
/* Table A3 */

use adjacency1, clear;
keep if inc == 0;

areg v12 instate, a(race) cluster(race);
local treat1 = _b[instate];
local se1 = _se[instate];
local n1 = e(N);
local c1 = _b[_cons];
local sec1 = _se[_cons];

areg v12 instate if tot_q_major == 0 & tot_q_stleg == 0, a(race) cluster(race);
local treat2 = _b[instate];
local se2 = _se[instate];
local n2 = e(N);
local c2 = _b[_cons];
local sec2 = _se[_cons];


use adjacency2, clear;
keep if inc == 0;

areg county_vote instate, a(race) cluster(race);
local treat3 = _b[instate];
local se3 = _se[instate];
local n3 = e(N);
local c3 = _b[_cons];
local sec3 = _se[_cons];

areg county_vote instate if tot_q_major == 0 & tot_q_stleg == 0, a(race) cluster(race);
local treat4 = _b[instate];
local se4 = _se[instate];
local n4 = e(N);
local c4 = _b[_cons];
local sec4 = _se[_cons];




set linesize 200;
capture log close;

quietly {;
log using county_no_inc.tex, text replace;
noisily display "";
noisily display "\begin{table}[htbp] \caption{\bf County-Level Analysis, No Incumbents} \label{tab:county_noinc}";
noisily display "\begin{center}";
noisily display "\footnotesize";
noisily display "\begin{tabular}{l*{5}{c}}";
noisily display "\toprule\toprule";
noisily display " & \multicolumn{2}{c}{All Counties} & & \multicolumn{2}{c}{Adjacent Counties} \\";
noisily display "   \cline{2-3}  \cline{5-6} \\ ";
noisily display " & \shortstack{Vote Pct,\\ Top 2} & \shortstack{Vote Pct,\\ Top 2} & & \shortstack{Vote Pct,\\ Top 2} & \shortstack{Vote Pct,\\ Top 2}\\";
noisily display " \midrule ";
noisily display " In-State Media Market ($\beta_1$) & " %4.2f `treat1' " & " %4.2f `treat2' " & & " %4.2f `treat3' " & " %4.2f `treat4' " \\[1mm]";
noisily display " & (" %4.2f `se1' ") & (" %4.2f `se2' ") & & (" %4.2f `se3' ") & (" %4.2f `se4' ") \\[1mm]";

noisily display " Out-of-State Media Market ($\beta_0$) & " %4.2f `c1' " & " %4.2f `c2' " & & " %4.2f `c3' " & " %4.2f `c4' " \\[1mm]";
noisily display " & (" %4.2f `sec1' ") & (" %4.2f `sec2' ") & & (" %4.2f `sec3' ") & (" %4.2f `sec4' ") \\[1mm]";

noisily display "\midrule";
noisily display " N & " %6.0fc `n1' " & " %5.0fc `n2' " & & " %5.0fc `n3' " & " %5.0fc `n4' " \\ ";
noisily display " Race Fixed Effects & Yes & Yes & & Yes & Yes \\";
noisily display "Races Included & All & No Experience & & All & No Experience \\";
noisily display " \bottomrule \bottomrule ";
noisily display "\multicolumn{6}{p{.8\textwidth}}{Robust standard errors clustered by race in parentheses. Out-of-State Media Markets are the omitted category ($\beta_0$).}";
noisily display "\end{tabular}";
noisily display "\end{center}";
noisily display "\end{table}";
log off;
};





